==> types_aiobotocore_iot_jobs_data-2.3.4.post2-py3-none-any.whl: types_aiobotocore_iot_jobs_data/type_defs.py <==
"""
Type annotations for iot-jobs-data service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot_jobs_data/type_defs/)

Usage::

    ```python
    from types_aiobotocore_iot_jobs_data.type_defs import DescribeJobExecutionRequestRequestTypeDef

    data: DescribeJobExecutionRequestRequestTypeDef = {...}
    ```
"""
import sys
from typing import Dict, List, Mapping

from .literals import JobExecutionStatusType

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "DescribeJobExecutionRequestRequestTypeDef",
    "JobExecutionTypeDef",
    "ResponseMetadataTypeDef",
    "GetPendingJobExecutionsRequestRequestTypeDef",
    "JobExecutionSummaryTypeDef",
    "JobExecutionStateTypeDef",
    "StartNextPendingJobExecutionRequestRequestTypeDef",
    "UpdateJobExecutionRequestRequestTypeDef",
    "DescribeJobExecutionResponseTypeDef",
    "StartNextPendingJobExecutionResponseTypeDef",
    "GetPendingJobExecutionsResponseTypeDef",
    "UpdateJobExecutionResponseTypeDef",
)

_RequiredDescribeJobExecutionRequestRequestTypeDef = TypedDict(
    "_RequiredDescribeJobExecutionRequestRequestTypeDef",
    {
        "jobId": str,
        "thingName": str,
    },
)
_OptionalDescribeJobExecutionRequestRequestTypeDef = TypedDict(
    "_OptionalDescribeJobExecutionRequestRequestTypeDef",
    {
        "includeJobDocument": bool,
        "executionNumber": int,
    },
    total=False,
)


class DescribeJobExecutionRequestRequestTypeDef(
    _RequiredDescribeJobExecutionRequestRequestTypeDef,
    _OptionalDescribeJobExecutionRequestRequestTypeDef,
):
    pass


JobExecutionTypeDef = TypedDict(
    "JobExecutionTypeDef",
    {
        "jobId": str,
        "thingName": str,
        "status": JobExecutionStatusType,
        "statusDetails": Dict[str, str],
        "queuedAt": int,
        "startedAt": int,
        "lastUpdatedAt": int,
        "approximateSecondsBeforeTimedOut": int,
        "versionNumber": int,
        "executionNumber": int,
        "jobDocument": str,
    },
    total=False,
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

GetPendingJobExecutionsRequestRequestTypeDef = TypedDict(
    "GetPendingJobExecutionsRequestRequestTypeDef",
    {
        "thingName": str,
    },
)

JobExecutionSummaryTypeDef = TypedDict(
    "JobExecutionSummaryTypeDef",
    {
        "jobId": str,
        "queuedAt": int,
        "startedAt": int,
        "lastUpdatedAt": int,
        "versionNumber": int,
        "executionNumber": int,
    },
    total=False,
)

JobExecutionStateTypeDef = TypedDict(
    "JobExecutionStateTypeDef",
    {
        "status": JobExecutionStatusType,
        "statusDetails": Dict[str, str],
        "versionNumber": int,
    },
    total=False,
)

_RequiredStartNextPendingJobExecutionRequestRequestTypeDef = TypedDict(
    "_RequiredStartNextPendingJobExecutionRequestRequestTypeDef",
    {
        "thingName": str,
    },
)
_OptionalStartNextPendingJobExecutionRequestRequestTypeDef = TypedDict(
    "_OptionalStartNextPendingJobExecutionRequestRequestTypeDef",
    {
        "statusDetails": Mapping[str, str],
        "stepTimeoutInMinutes": int,
    },
    total=False,
)


class StartNextPendingJobExecutionRequestRequestTypeDef(
    _RequiredStartNextPendingJobExecutionRequestRequestTypeDef,
    _OptionalStartNextPendingJobExecutionRequestRequestTypeDef,
):
    pass


_RequiredUpdateJobExecutionRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateJobExecutionRequestRequestTypeDef",
    {
        "jobId": str,
        "thingName": str,
        "status": JobExecutionStatusType,
    },
)
_OptionalUpdateJobExecutionRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateJobExecutionRequestRequestTypeDef",
    {
        "statusDetails": Mapping[str, str],
        "stepTimeoutInMinutes": int,
        "expectedVersion": int,
        "includeJobExecutionState": bool,
        "includeJobDocument": bool,
        "executionNumber": int,
    },
    total=False,
)


class UpdateJobExecutionRequestRequestTypeDef(
    _RequiredUpdateJobExecutionRequestRequestTypeDef,
    _OptionalUpdateJobExecutionRequestRequestTypeDef,
):
    pass


DescribeJobExecutionResponseTypeDef = TypedDict(
    "DescribeJobExecutionResponseTypeDef",
    {
        "execution": JobExecutionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

StartNextPendingJobExecutionResponseTypeDef = TypedDict(
    "StartNextPendingJobExecutionResponseTypeDef",
    {
        "execution": JobExecutionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetPendingJobExecutionsResponseTypeDef = TypedDict(
    "GetPendingJobExecutionsResponseTypeDef",
    {
        "inProgressJobs": List[JobExecutionSummaryTypeDef],
        "queuedJobs": List[JobExecutionSummaryTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateJobExecutionResponseTypeDef = TypedDict(
    "UpdateJobExecutionResponseTypeDef",
    {
        "executionState": JobExecutionStateTypeDef,
        "jobDocument": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

==> types_aiobotocore_iot_jobs_data-2.13.0-py3-none-any.whl: types_aiobotocore_iot_jobs_data/type_defs.py <==
"""
Type annotations for iot-jobs-data service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot_jobs_data/type_defs/)

Usage::

    ```python
    from types_aiobotocore_iot_jobs_data.type_defs import DescribeJobExecutionRequestRequestTypeDef

    data: DescribeJobExecutionRequestRequestTypeDef = ...
    ```
"""

import sys
from typing import Dict, List, Mapping

from .literals import JobExecutionStatusType

if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "DescribeJobExecutionRequestRequestTypeDef",
    "JobExecutionTypeDef",
    "ResponseMetadataTypeDef",
    "GetPendingJobExecutionsRequestRequestTypeDef",
    "JobExecutionSummaryTypeDef",
    "JobExecutionStateTypeDef",
    "StartNextPendingJobExecutionRequestRequestTypeDef",
    "UpdateJobExecutionRequestRequestTypeDef",
    "DescribeJobExecutionResponseTypeDef",
    "StartNextPendingJobExecutionResponseTypeDef",
    "GetPendingJobExecutionsResponseTypeDef",
    "UpdateJobExecutionResponseTypeDef",
)

DescribeJobExecutionRequestRequestTypeDef = TypedDict(
    "DescribeJobExecutionRequestRequestTypeDef",
    {
        "jobId": str,
        "thingName": str,
        "includeJobDocument": NotRequired[bool],
        "executionNumber": NotRequired[int],
    },
)
JobExecutionTypeDef = TypedDict(
    "JobExecutionTypeDef",
    {
        "jobId": NotRequired[str],
        "thingName": NotRequired[str],
        "status": NotRequired[JobExecutionStatusType],
        "statusDetails": NotRequired[Dict[str, str]],
        "queuedAt": NotRequired[int],
        "startedAt": NotRequired[int],
        "lastUpdatedAt": NotRequired[int],
        "approximateSecondsBeforeTimedOut": NotRequired[int],
        "versionNumber": NotRequired[int],
        "executionNumber": NotRequired[int],
        "jobDocument": NotRequired[str],
    },
)
ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
        "HostId": NotRequired[str],
    },
)
GetPendingJobExecutionsRequestRequestTypeDef = TypedDict(
    "GetPendingJobExecutionsRequestRequestTypeDef",
    {
        "thingName": str,
    },
)
JobExecutionSummaryTypeDef = TypedDict(
    "JobExecutionSummaryTypeDef",
    {
        "jobId": NotRequired[str],
        "queuedAt": NotRequired[int],
        "startedAt": NotRequired[int],
        "lastUpdatedAt": NotRequired[int],
        "versionNumber": NotRequired[int],
        "executionNumber": NotRequired[int],
    },
)
JobExecutionStateTypeDef = TypedDict(
    "JobExecutionStateTypeDef",
    {
        "status": NotRequired[JobExecutionStatusType],
        "statusDetails": NotRequired[Dict[str, str]],
        "versionNumber": NotRequired[int],
    },
)
StartNextPendingJobExecutionRequestRequestTypeDef = TypedDict(
    "StartNextPendingJobExecutionRequestRequestTypeDef",
    {
        "thingName": str,
        "statusDetails": NotRequired[Mapping[str, str]],
        "stepTimeoutInMinutes": NotRequired[int],
    },
)
UpdateJobExecutionRequestRequestTypeDef = TypedDict(
    "UpdateJobExecutionRequestRequestTypeDef",
    {
        "jobId": str,
        "thingName": str,
        "status": JobExecutionStatusType,
        "statusDetails": NotRequired[Mapping[str, str]],
        "stepTimeoutInMinutes": NotRequired[int],
        "expectedVersion": NotRequired[int],
        "includeJobExecutionState": NotRequired[bool],
        "includeJobDocument": NotRequired[bool],
        "executionNumber": NotRequired[int],
    },
)
DescribeJobExecutionResponseTypeDef = TypedDict(
    "DescribeJobExecutionResponseTypeDef",
    {
        "execution": JobExecutionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
StartNextPendingJobExecutionResponseTypeDef = TypedDict(
    "StartNextPendingJobExecutionResponseTypeDef",
    {
        "execution": JobExecutionTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetPendingJobExecutionsResponseTypeDef = TypedDict(
    "GetPendingJobExecutionsResponseTypeDef",
    {
        "inProgressJobs": List[JobExecutionSummaryTypeDef],
        "queuedJobs": List[JobExecutionSummaryTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
UpdateJobExecutionResponseTypeDef = TypedDict(
    "UpdateJobExecutionResponseTypeDef",
    {
        "executionState": JobExecutionStateTypeDef,
        "jobDocument": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
